(_lib)=
# Library Functionality

[Lineshapes](lineshape.md)
: How lineshapes (spectral, spatial, etc.) can be defined through `skretrieval`.

[Minimizers](minimizer.md)
: Various minimizers available to minimize the cost function

```{toctree}
:maxdepth: 4
:hidden:

lineshape
minimizer

```
